MapLauncherDesktop class

Desktop (macOS, Windows, Linux) implementation.

Uses system commands to open URLs in the default browser. Registered via dartPluginClass in pubspec.yaml.

Inheritance

Constructors

MapLauncherDesktop()

Properties

hashCode int
The hash code for this object.
no setterinherited
platform MapPlatform?
The platform this app is running on, or null on web/desktop.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInstalledMaps(List<MapApp> maps) Future<Set<String>>
Returns the ids of maps (from maps) that have native apps installed.
override
launch(String url, {String? androidPackageName}) Future<void>
Launch a URL. Opens in the native app if it handles the URL, otherwise opens in the default browser.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith() → void
Registers this class as the platform implementation.