MapLauncherPlatform class abstract

The platform interface for the MapLauncher plugin.

This defines the contract for platform-specific implementations. The platform layer is intentionally thin. It only handles:

  1. Launching URLs (opening in browser/app)
  2. Detecting installed native apps (mobile only)
Inheritance
  • Object
  • PlatformInterface
  • MapLauncherPlatform
Implementers

Constructors

MapLauncherPlatform()
Creates a MapLauncherPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
platform MapPlatform?
The platform this app is running on, or null on web/desktop.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInstalledMaps(List<MapApp> maps) Future<Set<String>>
Returns the ids of maps (from maps) that have native apps installed.
launch(String url, {String? androidPackageName}) Future<void>
Launch a URL. Opens in the native app if it handles the URL, otherwise opens in the default browser.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MapLauncherPlatform
The default instance of MapLauncherPlatform.
getter/setter pair