launch method

Future<void> launch(
  1. String url, {
  2. String? androidPackageName,
})

Launch a URL. Opens in the native app if it handles the URL, otherwise opens in the default browser.

On Android, androidPackageName targets the specific app package so the system resolver doesn't open a different app (e.g. Go vs Maps).

Implementation

Future<void> launch(String url, {String? androidPackageName}) {
  throw UnimplementedError('launch() has not been implemented.');
}