MapLauncherWeb class

Web implementation.

Uses window.open() to open map URLs in a new browser tab. Registered via pluginClass / fileName in pubspec.yaml.

Inheritance

Constructors

MapLauncherWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
platform MapPlatform?
The platform this app is running on, or null on web/desktop.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInstalledMaps(List<MapApp> maps) Future<Set<String>>
Returns the ids of maps (from maps) that have native apps installed.
override
launch(String url, {String? androidPackageName}) Future<void>
Launch a URL. Opens in the native app if it handles the URL, otherwise opens in the default browser.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith([Object? registrar]) → void
Registers this class as the platform implementation.