launch method

  1. @override
Future<void> launch(
  1. String url, {
  2. String? androidPackageName,
})
override

Launch a URL. Opens in the native app if it handles the URL, otherwise opens in the default browser.

On Android, androidPackageName targets the specific app package so the system resolver doesn't open a different app (e.g. Go vs Maps).

Implementation

@override
Future<void> launch(String url, {String? androidPackageName}) async {
  web.window.open(url, '_blank');
}