YandexMaps class
Yandex Maps. Supports coordinates, directions with origin, waypoints, and travel mode.
Constructors
- YandexMaps()
-
Creates a YandexMaps.
const
Properties
- appStoreId → String?
-
Apple App Store numeric identifier (iOS).
no setteroverride
- appStoreUrl → String?
-
Apple App Store URL, or
nullif not available on iOS.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hasUniversalLink → bool
-
Whether this map supports universal links (HTTPS URLs) that work
across all platforms, including desktop and web.
no setteroverride
- iconBytes → Uint8List
-
App icon as PNG bytes (256×256).
no setteroverride
- id → String
-
Stable identifier for this map (e.g.
'google','neshan').no setteroverride - iosScheme → String?
-
iOS URL scheme for
canOpenURLdetection (e.g.'comgooglemaps://').no setteroverride - name → String
-
Human-readable display name (e.g.
'Google Maps').no setteroverride - playStoreId → String?
-
Google Play Store package identifier (Android).
no setteroverride
- playStoreUrl → String?
-
Google Play Store URL, or
nullif not available on Android.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsDirectionsCoords → bool
-
Whether this map supports directions via coordinates.
no setterinherited
- supportsDirectionsSearch → bool
-
Whether this map supports directions via text search query.
no setterinherited
- supportsMarkerCoords → bool
-
Whether this map supports markers via coordinates.
no setterinherited
- supportsMarkerSearch → bool
-
Whether this map supports markers via text search query.
no setterinherited
- supportsWaypoints → bool
-
Whether this map supports waypoints in directions.
no setteroverride
Methods
-
bestDirectionsUrl(
{required Location destination, LocationCoords? origin, List< LocationCoords> ? waypoints, TravelMode? travelMode, MapPlatform? platform}) → String? -
Returns the best URL for directions.
inherited
-
bestMarkerUrl(
Location location, {int? zoom, MapPlatform? platform}) → String? -
Returns the best URL for a marker.
inherited
-
directionsSchemeSearchUrl(
String query, {LocationCoords? origin, TravelMode? travelMode, required MapPlatform platform}) → String? -
Builds a URL scheme link for directions via text search (mobile-only).
inherited
-
directionsSchemeUrl(
{required LocationCoords destination, LocationCoords? origin, List< LocationCoords> ? waypoints, TravelMode? travelMode, required MapPlatform platform}) → String? -
Builds a URL scheme link for showing directions (mobile-only).
override
-
directionsSearchUrl(
String query, {LocationCoords? origin, TravelMode? travelMode}) → String? -
Builds a universal link (HTTPS) for showing directions via text search.
inherited
-
directionsUrl(
{required LocationCoords destination, LocationCoords? origin, List< LocationCoords> ? waypoints, TravelMode? travelMode}) → String -
Builds a universal link (HTTPS) for showing directions.
override
-
isAlwaysAvailable(
MapPlatform platform) → bool -
Whether this map is always available on
platformwithout detection.inherited -
markerSchemeSearchUrl(
String query, {required MapPlatform platform}) → String? -
Builds a URL scheme link for showing a marker via text search (mobile-only).
inherited
-
markerSchemeUrl(
LocationCoords coords, {int? zoom, required MapPlatform platform}) → String? -
Builds a URL scheme link for showing a marker (mobile-only).
override
-
markerSearchUrl(
String query) → String? -
Builds a universal link (HTTPS) for showing a marker via text search.
inherited
-
markerUrl(
LocationCoords coords, {int? zoom}) → String -
Builds a universal link (HTTPS) for showing a marker.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsTravelMode(
TravelMode mode) → bool -
Whether this map supports the given
modefor directions.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited