MethodChannelMapLauncher class
Method channel implementation for Android and iOS.
Handles URL launching via native intents and app detection via package manager / canOpenURL.
- Inheritance
-
- Object
- PlatformInterface
- MapLauncherPlatform
- MethodChannelMapLauncher
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used for platform communication.
final
- platform → MapPlatform?
-
The platform this app is running on, or
nullon web/desktop.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInstalledMaps(
) → Future< List< MapType> > -
Returns the list of MapTypes that have native apps installed.
Returns an empty list on platforms that don't support app detection.
override
-
launch(
String url, {MapType? mapType}) → Future< void> -
Launch a URL. Opens in the native app if it handles the URL,
otherwise opens in the default browser.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited