launch method

Future<void> launch(
  1. String url, {
  2. MapType? mapType,
})

Launch a URL. Opens in the native app if it handles the URL, otherwise opens in the default browser.

On Android, mapType is used to target the specific app package so the system resolver doesn't open a different app (e.g. Go vs Maps).

Implementation

Future<void> launch(String url, {MapType? mapType}) {
  throw UnimplementedError('launch() has not been implemented.');
}