launch method

  1. @override
Future<void> launch(
  1. String url, {
  2. MapType? mapType,
})
override

Launch a URL. Opens in the native app if it handles the URL, otherwise opens in the default browser.

On Android, mapType is used to target the specific app package so the system resolver doesn't open a different app (e.g. Go vs Maps).

Implementation

@override
Future<void> launch(String url, {MapType? mapType}) async {
  web.window.open(url, '_blank');
}